Method: Rib.shell
- Defined in:
- lib/rib.rb
.shell ⇒ Object
Convenient shell accessor, which would just give you current last shell or create one and load the config file. If you need a clean shell which does not load config file, use Shell.new instead.
47 48 49 50 51 52 |
# File 'lib/rib.rb', line 47 def shell shells.last || begin require_config if config_path && config_path != Skip (shells << Shell.new(config)).last end end |